==> huaweicloudsdkrocketmq-3.1.119-py2.py3-none-any.whl: huaweicloudsdkrocketmq/v2/model/list_rocket_mq_migration_task_request.py <==
# coding: utf-8

import six

from huaweicloudsdkcore.utils.http_utils import sanitize_for_serialization


class ListRocketMqMigrationTaskRequest:

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    sensitive_list = []

    openapi_types = {
        'instance_id': 'str',
        'id': 'str',
        'type': 'str',
        'offset': 'str',
        'limit': 'str',
        'name': 'str'
    }

    attribute_map = {
        'instance_id': 'instance_id',
        'id': 'id',
        'type': 'type',
        'offset': 'offset',
        'limit': 'limit',
        'name': 'name'
    }

    def __init__(self, instance_id=None, id=None, type=None, offset=None, limit=None, name=None):
        """ListRocketMqMigrationTaskRequest

        The model defined in huaweicloud sdk

        :param instance_id: 实例ID。
        :type instance_id: str
        :param id: 任务ID。
        :type id: str
        :param type: 查询类型。
        :type type: str
        :param offset: 当前页，从1开始。
        :type offset: str
        :param limit: 当前页大小。
        :type limit: str
        :param name: - 查询vhost列表时，该字段可为空。 - 查询exchange列表时，该字段为exchange所属vhost名称。 - 查询queue列表时，该字段为queue所属vhost-所属exchange，例vhost1-exchange1。
        :type name: str
        """
        
        

        self._instance_id = None
        self._id = None
        self._type = None
        self._offset = None
        self._limit = None
        self._name = None
        self.discriminator = None

        self.instance_id = instance_id
        if id is not None:
            self.id = id
        if type is not None:
            self.type = type
        if offset is not None:
            self.offset = offset
        if limit is not None:
            self.limit = limit
        if name is not None:
            self.name = name

    @property
    def instance_id(self):
        """Gets the instance_id of this ListRocketMqMigrationTaskRequest.

        实例ID。

        :return: The instance_id of this ListRocketMqMigrationTaskRequest.
        :rtype: str
        """
        return self._instance_id

    @instance_id.setter
    def instance_id(self, instance_id):
        """Sets the instance_id of this ListRocketMqMigrationTaskRequest.

        实例ID。

        :param instance_id: The instance_id of this ListRocketMqMigrationTaskRequest.
        :type instance_id: str
        """
        self._instance_id = instance_id

    @property
    def id(self):
        """Gets the id of this ListRocketMqMigrationTaskRequest.

        任务ID。

        :return: The id of this ListRocketMqMigrationTaskRequest.
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """Sets the id of this ListRocketMqMigrationTaskRequest.

        任务ID。

        :param id: The id of this ListRocketMqMigrationTaskRequest.
        :type id: str
        """
        self._id = id

    @property
    def type(self):
        """Gets the type of this ListRocketMqMigrationTaskRequest.

        查询类型。

        :return: The type of this ListRocketMqMigrationTaskRequest.
        :rtype: str
        """
        return self._type

    @type.setter
    def type(self, type):
        """Sets the type of this ListRocketMqMigrationTaskRequest.

        查询类型。

        :param type: The type of this ListRocketMqMigrationTaskRequest.
        :type type: str
        """
        self._type = type

    @property
    def offset(self):
        """Gets the offset of this ListRocketMqMigrationTaskRequest.

        当前页，从1开始。

        :return: The offset of this ListRocketMqMigrationTaskRequest.
        :rtype: str
        """
        return self._offset

    @offset.setter
    def offset(self, offset):
        """Sets the offset of this ListRocketMqMigrationTaskRequest.

        当前页，从1开始。

        :param offset: The offset of this ListRocketMqMigrationTaskRequest.
        :type offset: str
        """
        self._offset = offset

    @property
    def limit(self):
        """Gets the limit of this ListRocketMqMigrationTaskRequest.

        当前页大小。

        :return: The limit of this ListRocketMqMigrationTaskRequest.
        :rtype: str
        """
        return self._limit

    @limit.setter
    def limit(self, limit):
        """Sets the limit of this ListRocketMqMigrationTaskRequest.

        当前页大小。

        :param limit: The limit of this ListRocketMqMigrationTaskRequest.
        :type limit: str
        """
        self._limit = limit

    @property
    def name(self):
        """Gets the name of this ListRocketMqMigrationTaskRequest.

        - 查询vhost列表时，该字段可为空。 - 查询exchange列表时，该字段为exchange所属vhost名称。 - 查询queue列表时，该字段为queue所属vhost-所属exchange，例vhost1-exchange1。

        :return: The name of this ListRocketMqMigrationTaskRequest.
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this ListRocketMqMigrationTaskRequest.

        - 查询vhost列表时，该字段可为空。 - 查询exchange列表时，该字段为exchange所属vhost名称。 - 查询queue列表时，该字段为queue所属vhost-所属exchange，例vhost1-exchange1。

        :param name: The name of this ListRocketMqMigrationTaskRequest.
        :type name: str
        """
        self._name = name

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                if attr in self.sensitive_list:
                    result[attr] = "****"
                else:
                    result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        import simplejson as json
        if six.PY2:
            import sys
            reload(sys)
            sys.setdefaultencoding("utf-8")
        return json.dumps(sanitize_for_serialization(self), ensure_ascii=False)

    def __repr__(self):
        """For `print`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, ListRocketMqMigrationTaskRequest):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other

==> huaweicloudsdkrocketmq-3.1.155-py2.py3-none-any.whl: huaweicloudsdkrocketmq/v2/model/list_rocket_mq_migration_task_request.py <==
# coding: utf-8

import six

from huaweicloudsdkcore.utils.http_utils import sanitize_for_serialization


class ListRocketMqMigrationTaskRequest:

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    sensitive_list = []

    openapi_types = {
        'instance_id': 'str',
        'id': 'str',
        'type': 'str',
        'offset': 'str',
        'limit': 'str',
        'name': 'str'
    }

    attribute_map = {
        'instance_id': 'instance_id',
        'id': 'id',
        'type': 'type',
        'offset': 'offset',
        'limit': 'limit',
        'name': 'name'
    }

    def __init__(self, instance_id=None, id=None, type=None, offset=None, limit=None, name=None):
        r"""ListRocketMqMigrationTaskRequest

        The model defined in huaweicloud sdk

        :param instance_id: 实例ID。
        :type instance_id: str
        :param id: 任务ID。
        :type id: str
        :param type: 查询类型。
        :type type: str
        :param offset: 当前页，从1开始。
        :type offset: str
        :param limit: 当前页大小。
        :type limit: str
        :param name: - 查询vhost列表时，该字段可为空。 - 查询exchange列表时，该字段为exchange所属vhost名称。 - 查询queue列表时，该字段为queue所属vhost-所属exchange，例vhost1-exchange1。
        :type name: str
        """
        
        

        self._instance_id = None
        self._id = None
        self._type = None
        self._offset = None
        self._limit = None
        self._name = None
        self.discriminator = None

        self.instance_id = instance_id
        if id is not None:
            self.id = id
        if type is not None:
            self.type = type
        if offset is not None:
            self.offset = offset
        if limit is not None:
            self.limit = limit
        if name is not None:
            self.name = name

    @property
    def instance_id(self):
        r"""Gets the instance_id of this ListRocketMqMigrationTaskRequest.

        实例ID。

        :return: The instance_id of this ListRocketMqMigrationTaskRequest.
        :rtype: str
        """
        return self._instance_id

    @instance_id.setter
    def instance_id(self, instance_id):
        r"""Sets the instance_id of this ListRocketMqMigrationTaskRequest.

        实例ID。

        :param instance_id: The instance_id of this ListRocketMqMigrationTaskRequest.
        :type instance_id: str
        """
        self._instance_id = instance_id

    @property
    def id(self):
        r"""Gets the id of this ListRocketMqMigrationTaskRequest.

        任务ID。

        :return: The id of this ListRocketMqMigrationTaskRequest.
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        r"""Sets the id of this ListRocketMqMigrationTaskRequest.

        任务ID。

        :param id: The id of this ListRocketMqMigrationTaskRequest.
        :type id: str
        """
        self._id = id

    @property
    def type(self):
        r"""Gets the type of this ListRocketMqMigrationTaskRequest.

        查询类型。

        :return: The type of this ListRocketMqMigrationTaskRequest.
        :rtype: str
        """
        return self._type

    @type.setter
    def type(self, type):
        r"""Sets the type of this ListRocketMqMigrationTaskRequest.

        查询类型。

        :param type: The type of this ListRocketMqMigrationTaskRequest.
        :type type: str
        """
        self._type = type

    @property
    def offset(self):
        r"""Gets the offset of this ListRocketMqMigrationTaskRequest.

        当前页，从1开始。

        :return: The offset of this ListRocketMqMigrationTaskRequest.
        :rtype: str
        """
        return self._offset

    @offset.setter
    def offset(self, offset):
        r"""Sets the offset of this ListRocketMqMigrationTaskRequest.

        当前页，从1开始。

        :param offset: The offset of this ListRocketMqMigrationTaskRequest.
        :type offset: str
        """
        self._offset = offset

    @property
    def limit(self):
        r"""Gets the limit of this ListRocketMqMigrationTaskRequest.

        当前页大小。

        :return: The limit of this ListRocketMqMigrationTaskRequest.
        :rtype: str
        """
        return self._limit

    @limit.setter
    def limit(self, limit):
        r"""Sets the limit of this ListRocketMqMigrationTaskRequest.

        当前页大小。

        :param limit: The limit of this ListRocketMqMigrationTaskRequest.
        :type limit: str
        """
        self._limit = limit

    @property
    def name(self):
        r"""Gets the name of this ListRocketMqMigrationTaskRequest.

        - 查询vhost列表时，该字段可为空。 - 查询exchange列表时，该字段为exchange所属vhost名称。 - 查询queue列表时，该字段为queue所属vhost-所属exchange，例vhost1-exchange1。

        :return: The name of this ListRocketMqMigrationTaskRequest.
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        r"""Sets the name of this ListRocketMqMigrationTaskRequest.

        - 查询vhost列表时，该字段可为空。 - 查询exchange列表时，该字段为exchange所属vhost名称。 - 查询queue列表时，该字段为queue所属vhost-所属exchange，例vhost1-exchange1。

        :param name: The name of this ListRocketMqMigrationTaskRequest.
        :type name: str
        """
        self._name = name

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                if attr in self.sensitive_list:
                    result[attr] = "****"
                else:
                    result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        import simplejson as json
        if six.PY2:
            import sys
            reload(sys)
            sys.setdefaultencoding("utf-8")
        return json.dumps(sanitize_for_serialization(self), ensure_ascii=False)

    def __repr__(self):
        """For `print`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, ListRocketMqMigrationTaskRequest):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other
